==> folktale-2.3.0.tgz: package/annotated/validation/chain.js <==
'use strict';

var __metamagical_withMeta = function metamagical_withMeta(object, meta) {
  var parent = Object.getPrototypeOf(object);var oldMeta = object[Symbol.for('@@meta:magical')] || {};if (parent && parent[Symbol.for('@@meta:magical')] === oldMeta) {
    oldMeta = {};
  }Object.keys(meta).forEach(function (key) {
    if (/^~/.test(key)) {
      oldMeta[key.slice(1)] = meta[key];
    } else {
      oldMeta[key] = meta[key];
    }
  });object[Symbol.for('@@meta:magical')] = oldMeta;return object;
};

//----------------------------------------------------------------------
//
// This source file is part of the Folktale project.
//
// Licensed under MIT. See LICENCE for full licence information.
// See CONTRIBUTORS for the list of contributors to the project.
//
//----------------------------------------------------------------------

var _require = require('./validation'),
    _Failure = _require.Failure;

/*~
 * stability: experimental
 * type: |
 *   forall a, b, c: (Validation a b, (b) => Validation a c) => Validation a c
 */


var chain = __metamagical_withMeta(function (validation, fn) {
  return validation.matchWith({
    Success: function Success(_ref) {
      var value = _ref.value;
      return fn(value);
    },
    Failure: function Failure(_ref2) {
      var value = _ref2.value;
      return _Failure(value);
    }
  });
}, {
  'name': 'chain',
  'source': '(validation, fn) =>\r\n  validation.matchWith({\r\n    Success: ({ value }) => fn(value),\r\n    Failure: ({ value }) => Failure(value)\r\n  })',
  'signature': 'chain(validation, fn)',
  'location': {
    'filename': 'source/validation/chain.js',
    'start': {
      'line': 17,
      'column': 0
    },
    'end': {
      'line': 21,
      'column': 5
    }
  },
  'module': 'folktale/validation/chain',
  'licence': 'MIT',
  'authors': ['Quildreen Motta'],
  'repository': 'https://github.com/origamitower/folktale',
  'npmPackage': 'folktale',
  'copyright': '(c) 2013-2017 Quildreen Motta, and CONTRIBUTORS',
  'maintainers': ['Quildreen Motta <queen@robotlolita.me> (http://robotlolita.me/)'],
  'stability': 'experimental',
  'type': 'forall a, b, c: (Validation a b, (b) => Validation a c) => Validation a c\n'
});

module.exports = chain;

==> folktale-2.3.2.tgz: package/annotated/validation/chain.js <==
'use strict';

var __metamagical_withMeta = function metamagical_withMeta(object, meta) {
  var parent = Object.getPrototypeOf(object);var oldMeta = object[Symbol.for('@@meta:magical')] || {};if (parent && parent[Symbol.for('@@meta:magical')] === oldMeta) {
    oldMeta = {};
  }Object.keys(meta).forEach(function (key) {
    if (/^~/.test(key)) {
      oldMeta[key.slice(1)] = meta[key];
    } else {
      oldMeta[key] = meta[key];
    }
  });object[Symbol.for('@@meta:magical')] = oldMeta;return object;
};

//----------------------------------------------------------------------
//
// This source file is part of the Folktale project.
//
// Licensed under MIT. See LICENCE for full licence information.
// See CONTRIBUTORS for the list of contributors to the project.
//
//----------------------------------------------------------------------

var _require = require('./validation'),
    _Failure = _require.Failure;

/*~
 * stability: stable
 * type: |
 *   forall a, b, c: (Validation a b, (b) => Validation a c) => Validation a c
 */


var chain = __metamagical_withMeta(function (validation, fn) {
  return validation.matchWith({
    Success: function Success(_ref) {
      var value = _ref.value;
      return fn(value);
    },
    Failure: function Failure(_ref2) {
      var value = _ref2.value;
      return _Failure(value);
    }
  });
}, {
  'name': 'chain',
  'source': '(validation, fn) =>\n  validation.matchWith({\n    Success: ({ value }) => fn(value),\n    Failure: ({ value }) => Failure(value)\n  })',
  'signature': 'chain(validation, fn)',
  'location': {
    'filename': 'source/validation/chain.js',
    'start': {
      'line': 17,
      'column': 0
    },
    'end': {
      'line': 21,
      'column': 5
    }
  },
  'module': 'folktale/validation/chain',
  'licence': 'MIT',
  'authors': ['Quildreen Motta'],
  'repository': 'https://github.com/origamitower/folktale',
  'npmPackage': 'folktale',
  'copyright': '(c) 2013-2017 Quildreen Motta, and CONTRIBUTORS',
  'maintainers': ['Quildreen Motta <queen@robotlolita.me> (http://robotlolita.me/)'],
  'stability': 'stable',
  'type': 'forall a, b, c: (Validation a b, (b) => Validation a c) => Validation a c\n'
});

module.exports = chain;
